@@ -13,6 +13,7 @@ import os
 import glob
 import collections
 import pymeshfix
+import sys
 
 
 
@@ -48,20 +49,31 @@ def fixNonWatertight(mesh):
 
     return False
 
+class recursion_depth:
+    def __init__(self, limit):
+        self.limit = limit
+        self.default_limit = sys.getrecursionlimit()
+    def __enter__(self):
+        sys.setrecursionlimit(self.limit)
+    def __exit__(self, type, value, traceback):
+        sys.setrecursionlimit(self.default_limit)
+
 def removeEyeBalls(mesh):
     # get max z vertex
+
     vertex_z_max_index = mesh.vertices[:, 2].argmax()
+    with recursion_depth(150000000):
 
-    def get_vertices_connect_vertex(mesh, vertex, path=[]):
-        path += [vertex]
+        def get_vertices_connect_vertex(mesh, vertex, path=[]):
+            path += [vertex]
 
-        for neighbor in list(mesh.vertex_adjacency_graph[vertex]):
-            if neighbor not in path:
-                path = get_vertices_connect_vertex(mesh, neighbor, path)
+            for neighbor in list(mesh.vertex_adjacency_graph[vertex]):
+                if neighbor not in path:
+                    path = get_vertices_connect_vertex(mesh, neighbor, path)
 
-        return path
+            return path
 
-    vertices_connect = get_vertices_connect_vertex(mesh, vertex_z_max_index)
+        vertices_connect = get_vertices_connect_vertex(mesh, vertex_z_max_index)
 
     vertices = np.array(mesh.vertices)
     faces = np.array(mesh.faces)
